==> openwebbeans-1.2.8-source-release.zip: openwebbeans-1.2.8/webbeans-impl/src/test/java/org/apache/webbeans/test/component/PreDestroyComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.enterprise.context.RequestScoped;
import javax.inject.Inject;

import org.apache.webbeans.test.annotation.binding.Check;

@RequestScoped
public class PreDestroyComponent
{
    private @Inject @Check(type = "CHECK") IPayment payment;

    private IPayment p = null;

    private IPayment p2 = null;

    private static boolean destroyed;

    @PostConstruct
    public void init()
    {
        this.p = payment;
        destroyed = false;
    }

    @PreDestroy
    public void destroy()
    {
        p2 = p;
        destroyed = true;
    }

    public IPayment getP()
    {
        return payment;
    }

    public IPayment getP2()
    {
        return p2;
    }

    public static boolean isDestroyed()
    {
        return destroyed;
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/component/PreDestroyComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component;

import jakarta.annotation.PostConstruct;
import jakarta.annotation.PreDestroy;
import jakarta.enterprise.context.RequestScoped;
import jakarta.inject.Inject;

import org.apache.webbeans.test.annotation.binding.Check;

@RequestScoped
public class PreDestroyComponent
{
    private @Inject @Check(type = "CHECK") IPayment payment;

    private IPayment p = null;

    private IPayment p2 = null;

    private static boolean destroyed;

    @PostConstruct
    public void init()
    {
        this.p = payment;
        destroyed = false;
    }

    @PreDestroy
    public void destroy()
    {
        p2 = p;
        destroyed = true;
    }

    public IPayment getP()
    {
        return payment;
    }

    public IPayment getP2()
    {
        return p2;
    }

    public static boolean isDestroyed()
    {
        return destroyed;
    }
}
